@@ -5,7 +5,7 @@ use utf8;
 # Author          : Johan Vromans
 # Created On      : Sat Oct  8 16:40:43 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Tue Jan 31 12:02:01 2017
+# Last Modified On: Thu Jan 26 19:51:03 2017
 # Update Count    : 178
 # Status          : Unknown, Use with caution!
 
@@ -21,7 +21,7 @@ use EB;
 
 use IO::File;
 use EB::Format;
-use File::Glob ( $] >= 5.016 ? ":bsd_glob" : ":glob" );
+use File::Glob qw( :bsd_glob );	# glob that allows space (for Windows);
 
 sub new {
     my ($class, $opts) = @_;
@@ -211,7 +211,7 @@ sub backend_options {
     my @opts = ( __xt("cmo:report:output")."=s",
 		 __xt("cmo:report:page")."=i" );
 
-    if ( $Cava::Packager::PACKAGED ) {
+    if ( $App::Packager::PACKAGED ) {
 	$be{wxhtml}++;
 	unless ( $be{wxhtml} ) {
 	    # Ignored, but forces the packager to include these modules.
